import requests
from GeoData.POIException import NoKeyError


class POI:
    def __init__(self):
        self.data_hub_url = 'http://datahub.wtf/api/MapPoiRouter/getPoiList'
        self.gaode_url = 'https://restapi.amap.com/v3/place/around '
        self.baidu_url = 'http://api.map.baidu.com/place/v2/search'
        self.header = {
            'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.129 Safari/537.36'}

    def get_data_hub_pois(self, **kws):
        resp = requests.get(
            self.data_hub_url, params=kws, headers=self.header)
        return resp.json()

    def get_gao_de_poi(self, key=None, **kws):
        if not key:
            raise NoKeyError(
                "没有高德地图开发者key异常，请上高德申请(https://lbs.amap.com/api/webservice/summary/)")
        kws.update({"key": key})
        resp = requests.get(self.gaode_url, headers=self.header, params=kws)
        return resp.json()

    def get_baidu_poi(self, key=None, **kws):
        if not key:
            raise NoKeyError(
                "没有百度地图开发者key异常，请上百度申请(http://lbsyun.baidu.com/index.php?title=webapi)")
        kws.update({"key": key})
        resp = requests.get(self.gaode_url, headers=self.header, params=kws)
        return resp.json()


if __name__ == '__main__':
    pass



# -*- coding: utf-8 -*-
"""
    点射线法判断
"""
class Geometry:
    def __init__(self,shapes):
        self.shapes = shapes

    def point_intersect_Geometry(self,point,isclose=True):
        """
        point点 是否在多边形内
        :param point:
        :return:
        内 返回 True
        外 返回 False
        """
        isIn = False
        if len(self.shapes)<2:
            return False
        for i,p1 in enumerate(self.shapes,1):
            if point==p1:
                return True
            if i == len(self.shapes) and (not isclose):
                p1 =  self.shapes[i-1]
                p2 = self.shapes[0]
            elif i == len(self.shapes) and isclose:
                continue
            else:
                p2  = self.shapes[i]
            if self.__point_horizontal_intersect_line(point,p1,p2):
                isIn = not isIn
        return isIn

    def __point_horizontal_intersect_line(self,p,p1,p2):
        """
        点p的水平正方向射线  与p1,p2连接线是否相交
        :param p:
        :param p1:
        :param p2:
        :return:
        相交返回 True
        不相交返回 False
        """
        if ((p1['y']-p['y'] > 0) == (p2['y'] - p['y'] > 0)):
            return False
        c_x = ((p1['x']-p2['x']) * (p['y']-p2['y']))/(p1['y']-p2['y']) + p2['x']
        return c_x >= p['x']

if __name__ == '__main__':
    pass
    # print(Geometry([]).point_intersect_line({"x":1,"y":1},{"x":3,"y":10},{"x":10,"y":0.2}))


# -*- coding: utf-8 -*- 
from math import radians, cos, sin, asin, sqrt, pi
import sys


class LocDisDir:
    def __init__(self):
        # 地球半径
        self.R = 6371 * 1000


    """计算两点间距离"""
    def geodistance(self, lng1, lat1, lng2, lat2):
        """

        :param lng1: 120.12802999999997
        :param lat1: 30.28708,115
        :param lng2: 115.86572000000001
        :param lat2: 28.7427
        :return: 两点间距离
        """
        lng1, lat1, lng2, lat2 = map(radians, [float(lng1), float(lat1), float(lng2), float(lat2)])  # 经纬度转换成弧度
        dlon = lng2 - lng1
        dlat = lat2 - lat1
        a = sin(dlat / 2) ** 2 + cos(lat1) * cos(lat2) * sin(dlon / 2) ** 2
        distance = 2 * asin(sqrt(a)) * self.R  # 地球平均半径，6371km
        distance = round(distance, 3)
        return distance

    """计算点经纬度北500米的点的经纬度"""

    def gps_north_dot(self, lng1, lat1, dist=500):
        """

        :param lng1: 120.12803
        :param lat1: 20.28708
        :param dist:
        :return: (120.12803, 20.291576608029594)
        """
        lat2 = 180 * dist / (self.R * pi) + lat1
        return (lng1, lat2)

    """计算点经纬度正东500米点的经纬度"""

    def gps_east_dot(self, lng1, lat1, dist=500):
        """

        :param lng1: 116.55272514141352
        :param lat1: 30.28708
        :param dist:
        :return: (116.55272514141352,30.28708)
        """
        lng2 = 180 * dist / (self.R * pi * cos(radians(lat1))) + lng1
        return (lng2, lat1)

    """计算点东北方向与正东某夹角某距离的经纬度"""

    def get_loc_with_angle(lng, lat, dist=500, angle=30):
        """

        :param lng:116.55272514141352
        :param lat:30.28708
        :param dist:指定距离
        :param angle:指定角度
        :return:（0.0091871843081617/pi + 116.498079 0.0122339171779312/pi + 39.752304）
        """
        R = 6371 * 1000
        lat_new = 180 * dist * sin(radians(angle)) / (R * pi) + lat
        lng_new = 180 * dist * cos(radians(angle)) / (R * pi * cos(radians(lat))) + lng
        return lng_new, lat_new


if __name__ == '__main__':
    functions = LocDisDir()
    lng1, lat1 = [116.498079, 39.752304]
    lng3, lat4 = [116.498079, 39.752304]
    # #计算正北的点
    # lng2, lat2 = functions.get_new_lat(lng1, lat1)
    # #计算正东的点
    # lng3, lat3 = functions.get_new_lng(lng1, lat1)
    # #计算夹角的点
    # lng4, lat4 = functions.get_new_lng_angle(lng1, lat1, dist=500, angle=90)
    # print("原始点的经纬度坐标", lng1, lat1)
    # print("正北500米坐标点为%f,%f,距离计算为%f米" % (lng2, lat2, functions.geodistance(lng1, lat1, lng2, lat2)))
    # print("正东500米坐标点为%f,%f,距离计算为%f米" % (lng3, lat3, functions.geodistance(lng1, lat1, lng3, lat3)))
    # print("东北方夹角，距离500米坐标点为%f,%f,距离计算为%f米" % (float(lng3), float(lat3), functions.geodistance(lng1, lat1, lng3, lat3)))
    # print(functions.geodistance(lng3, lat3, lng4, lat4))



from GeoData.POI import POI

poi = POI()

#请求自建数据
print(poi.get_data_hub_pois(lat='12',lon='13',page=1,pageSize=10))

#请求高德地图接口
print(poi.get_gao_de_poi(key=None, locations='123.12,45.12',page=1))

#请求百度地图接口
print(poi.get_baidu_poi(key=None, location='123.12,45.12',page=1))




# Copyright 2020 donggee.

"""
The setup script to install Geo SDK for python
"""
from __future__ import absolute_import
import io
import os
import re
try:
    from setuptools import setup,Extension
except ImportError:
    from distutils.core import setup

# with io.open(os.path.join("geo", "__init__.py"), "rt") as f:
#     SDK_VERSION = re.search(r"SDK_VERSION = b'(.*?)'", f.read()).group(1)
with open(os.path.join("./", "README.md"), "rt",encoding='utf-8') as f:
    LONG_DESC=f.read()

setup(
    name='geo_tools_py',
    version='v1.0.1',
    install_requires=['requests'],
    python_requires='>=2.7',
    packages=['GeoData','GeoCal','example'],
    url='http://datahub.wtf',
    license='Apache License 2.0',
    author='caidong',
    author_email='zhucaidong@aliyun.com',
    description='Geo SDK for python',
    long_description=LONG_DESC,
    long_description_content_type='text/markdown',
)
